@@ -1,6 +1,9 @@
 import hashlib
 import os.path
 import requests
+import re
+import time
+import urllib.parse
 
 from json import JSONDecodeError
 
@@ -202,8 +205,6 @@ class Client:
 
                             # Read next chunk and continue
                             chunk = build_file.read(CHUNK_SIZE)
-                        elif r.status_code == 429:
-                            upload_handle_rate_limit(r)
                         elif int(r.status_code / 100) == 4:
                             upload_handle_4xx_response(r)
                         else:
@@ -273,45 +274,61 @@ class Client:
 
         return header
 
-    def _post(self, url, headers=None, data=None):
+    def _request(self, type, url, headers=None, data=None, files=None):
+        request_url = urllib.parse.urljoin(self.server_url, url)
         log_debug_request_send(
-            request_type="POST",
-            url=f"{self.server_url}{url}",
+            request_type=type,
+            url=request_url,
             headers=headers,
             data=data,
         )
-        r = requests.post(
-            url=f"{self.server_url}{url}",
-            headers=headers,
-            data=data,
-            allow_redirects=False,
-        )
+        match type:
+            case "GET":
+                r = requests.get(url=request_url, headers=headers, data=data)
+            case "POST":
+                r = requests.post(
+                    url=request_url,
+                    headers=headers,
+                    data=data,
+                    allow_redirects=False,
+                )
+            case "PUT":
+                r = requests.put(
+                    url=request_url,
+                    headers=headers,
+                    data=data,
+                    files=files,
+                )
+            case _:
+                return
         log_debug_request_response(r)
+
+        # Check for rate limit
+        if r.status_code == 429:
+            print(RATE_LIMIT_MSG)
+            self._wait_rate_limit(int(re.findall(r"\d+", r.json()["detail"])[0]))
+
+            return self._request(
+                type=type, url=url, headers=headers, data=data, files=files
+            )
+
         return r
 
+    def _wait_rate_limit(seconds):
+        with console.status(RATE_LIMIT_WAIT_STATUS_MSG.format(seconds)) as status:
+            while seconds:
+                time.sleep(1)
+                seconds -= 1
+                status.update(status=RATE_LIMIT_WAIT_STATUS_MSG.format(seconds))
+
+    def _post(self, url, headers=None, data=None):
+        return self._request("POST", url, headers, data)
+
     def _get(self, url, headers=None, data=None):
-        log_debug_request_send(
-            request_type="GET",
-            url=f"{self.server_url}{url}",
-            headers=headers,
-            data=data,
-        )
-        r = requests.get(url=f"{self.server_url}{url}", headers=headers, data=data)
-        log_debug_request_response(r)
-        return r
+        return self._request("GET", url, headers, data)
 
     def _put(self, url, headers, data, files):
-        log_debug_request_send(
-            request_type="PUT",
-            url=f"{self.server_url}{url}",
-            headers=headers,
-            data=data,
-        )
-        r = requests.put(
-            url=f"{self.server_url}{url}", headers=headers, data=data, files=files
-        )
-        log_debug_request_response(r)
-        return r
+        return self._request("PUT", url, headers, data, files)
 
 
 def handle_undefined_response(request):
@@ -330,13 +347,6 @@ def handle_undefined_response(request):
         )
 
 
-def upload_handle_rate_limit(chunk_request):
-    print(RATE_LIMIT_MSG)
-    import re
-
-    wait_rate_limit(int(re.findall(r"\d+", chunk_request.json()["detail"])[0]))
-
-
 def upload_handle_4xx_response(chunk_request):
     try:
         response_json = chunk_request.json()
@@ -381,16 +391,6 @@ def find_checksum_file(filename):
     return has_checksum_file_type, has_sum_postfix
 
 
-def wait_rate_limit(s):
-    import time
-
-    with console.status(RATE_LIMIT_WAIT_STATUS_MSG.format(s)) as status:
-        while s:
-            time.sleep(1)
-            s -= 1
-            status.update(status=RATE_LIMIT_WAIT_STATUS_MSG.format(s))
-
-
 def upload_exception_check(request, build_file):
     if request.status_code == 200:
         print(f"Successfully uploaded the build {build_file}!")
